# Alquran CLI
CLI Sederhana untuk mengambil isi-isi surah al-Quran dan tafsirnya serta riwayat-riwayat hadits.

## Instalasi
Cara 1 :
```bash
pip install alquran-cli
```
Cara 2 :
```bash
git clone https://github.com/anggiAnand/alquran-cli.git

cd alquran-cli

pip install .
```
Cara 3 :
```bash
pip install git+https://github.com/anggiAnand/alquran-cli
```

## Usage
Jika sudah install dari pip
```bash
alquran --help
```
Jika belum
```bash
pip install requirements.txt

python3 alquran/alquran.py --help
```
